#
# spec file for package libuv
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define somajor 1
Name:           libuv
Version:        1.18.0
Release:        lp152.4.3.1
Summary:        Asychronous I/O support library
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://libuv.org
# Using URL from upstream project fails due to ipv6 redirect
# Source0:      http://dist.libuv.org/dist/v%{version}/libuv-v%{version}.tar.gz
# Source1:      http://dist.libuv.org/dist/v%{version}/libuv-v%{version}.tar.gz.sign
# Source2:      %{name}.keyring
Source0:        https://github.com/libuv/libuv/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:	baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libuv is a support library with a focus on asynchronous I/O. It was
primarily developed for use by Node.js, but it is also used by
Mozilla's Rust language, Luvit, Julia, pyuv, and others.

%package     -n libuv%{somajor}
Summary:        Asychronous I/O support library
Group:          System/Libraries

%description -n libuv%{somajor}
libuv is a support library with a focus on asynchronous I/O. It was
primarily developed for use by Node.js, but it is also used by
Mozilla's Rust language, Luvit, Julia, pyuv, and others.

%package        devel
Summary:        Development libraries for libuv
Group:          Development/Libraries/C and C++
BuildRequires:  glibc-devel
Requires:       libuv%{somajor} = %{version}

%description    devel
Development files for libuv.

libuv is a support library with a focus on asynchronous I/O. It was
primarily developed for use by Node.js, but it is also used by
Mozilla's Rust language, Luvit, Julia, pyuv, and others.

%prep
%setup -q

%build
./autogen.sh
%configure \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
# Tests sadly fail
#make %{?_smp_mflags} check

%post -n libuv%{somajor} -p /sbin/ldconfig
%postun -n libuv%{somajor} -p /sbin/ldconfig

%files -n libuv%{somajor}
%{_libdir}/libuv.so.%{somajor}*

%files devel
%doc AUTHORS CONTRIBUTING.md ChangeLog LICENSE README.md
%{_libdir}/libuv.so
%{_includedir}/uv*
%{_libdir}/pkgconfig/libuv.pc

%changelog
* Fri Oct 16 2020 Marcus Meissner <meissner@suse.com>
- add baselibs.conf, as we need 32bit libs for bind.
* Sun Dec 24 2017 avindra@opensuse.org
- Update to version 1.18.0
  * unix,win: add uv_os_getpid()
  * unix: remove incorrect assertion in uv_shutdown()
  * aix: fix -Wmaybe-uninitialized warning
  * win,doc: remove note about SIGWINCH on Windows
  * doc: fix IRC URL in CONTRIBUTING.md
- 1.17.0
  * ibmi: add support for new platform
  * unix: keep track of bound sockets sent via spawn
  * unix: avoid malloc() call in uv_spawn()
  * zos: add strnlen() implementation
  * test: add threadpool init/teardown test
  * test: avoid malloc() in threadpool test
  * test: lower number of tasks in threadpool test
  * test: fix test-spawn compilation
  * doc: clarify the description of uv_loop_alive()
  * win: issue memory barrier in uv_thread_join()
  * win: map UV_FS_O_EXLOCK to a share mode of 0
  * win: fix build on case-sensitive file systems
  * win: fix test runner build with mingw64
  * win: remove unused variable in test/test-fs.c
- 1.16.1
  * unix: move net/if.h include
  * win: fix undeclared NDIS_IF_MAX_STRING_SIZE
- 1.16.0
  * unix,win: add fs open flags, map O_DIRECT|O_DSYNC
  * win, fs: fix non-symlink reparse points
  * test: fix -Wstrict-prototypes warnings
  * unix, windows: map ENOTTY errno
  * unix: fall back to fsync() if F_FULLFSYNC fails
  * unix: do not close invalid kqueue fd after fork
  * zos: reset epoll data after fork
  * zos: skip fork_threadpool_queue_work_simple
  * test: keep platform_output as first test
  * unix,win: add uv_os_getppid()
  * test: fix const qualification compiler warning
  * doc: mark uv_default_loop() as not thread safe
  * win, pipe: null-initialize stream->shutdown_req
  * tty, win: get SetWinEventHook pointer at startup
  * test: no extra new line in skipped test output
  * pipe: allow access from other users
  * unix,win: add uv_if_{indextoname,indextoiid}
  * win: fix non-English dlopen error message
  * win: change st_blksize from `2048` to `4096`
- Small spec file cleanup
* Wed Nov  1 2017 mpluskal@suse.com
- Do not use source URL as fetching fails over ipv6
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 1.15.0:
  * win: fix buffer size in uv__getpwuid_r()
  * unix: use fchmod() in uv_fs_copyfile()
  * unix: support copying empty files
  * unix: truncate destination in uv_fs_copyfile()
  * linux: increase thread stack size with musl libc
  * test: clean up semaphore after use
  * unix: check for NULL in uv_os_unsetenv for parameter name
  * For extensive list of changes since last release see provided
    ChangeLog
- Small spec file cleanup
* Wed Nov 23 2016 qantas94heavy@gmail.com
- Update to 1.10.1
  * win: fix anonymous union syntax
  * unix: use uv__is_closing everywhere
  * win: add missing break statement
  * doc: fix wrong man page link for uv_fs_lstat()
  * win, tty: handle empty buffer in uv_tty_write_bufs
  * doc: add cjihrig alternative GPG ID
  * Revert "win,tty: add support for ANSI codes in win10 v1511"
- Add signature and keyring for GPG source verification
* Sun Nov 13 2016 aloisio@gmx.com
- Update to 1.10.0
* Wed Jul 27 2016 jengelh@inai.de
- Trim filler words from description
* Sat Jan 30 2016 mpluskal@suse.com
- Update to 1.8.0
  * unix: fix memory leak in uv_interface_addresses (Jianghua Yang)
  * unix: make uv_guess_handle work properly for AIX (Gireesh
    Punathil)
  * fs: undo uv__req_init when uv__malloc failed (Jianghua Yang)
  * build: remove unused 'component' GYP option (Saúl Ibarra
    Corretgé)
  * include: remove duplicate extern declaration (Jianghua Yang)
  * win: use the MSVC provided snprintf where possible (Jason
    Williams)
  * win, test: fix compilation warning (Saúl Ibarra Corretgé)
  * win: fix compilation with VS < 2012 (Ryan Johnston)
  * stream: support empty uv_try_write on unix (Fedor Indutny)
  * unix: fix request handle leak in uv__udp_send (Jianghua Yang)
  * src: replace QUEUE_SPLIT with QUEUE_MOVE (Ben Noordhuis)
  * unix: use QUEUE_MOVE when iterating over lists (Ben Noordhuis)
  * unix: squelch harmless valgrind warning (Ben Noordhuis)
  * test: don't abort on setrlimit() failure (Ben Noordhuis)
  * unix: only undo fs req registration in async mode (Ben
    Noordhuis)
  * unix: fix uv__getiovmax return value (HungMingWu)
  * unix: make work with Solaris Studio. (Adam Stylinski)
  * test: fix fs_event_watch_file_currentdir flakiness (Santiago
    Gimeno)
  * unix: skip prohibited syscalls on tvOS and watchOS (Nathan
    Corvino)
  * test: use FQDN in getaddrinfo_fail test (Wink Saville)
  * docs: clarify documentation of uv_tcp_init_ex (Andrius
    Bentkus)
  * win: fix comment (Miodrag Milanovic)
  * doc: fix typo in README (Angel Leon)
  * darwin: abort() if (un)locking fs mutex fails (Ben Noordhuis)
  * pipe: enable inprocess uv_write2 on Windows (Louis DeJardin)
  * win: properly return UV_EBADF when _close() fails (Nicholas
    Vavilov)
  * test: skip process_title for AIX (Imran Iqbal)
  * misc: expose handle print APIs (Petka Antonov)
  * include: add stdio.h to uv.h (Saúl Ibarra Corretgé)
  * misc: remove unnecessary null pointer checks (Ian Kronquist)
  * test,freebsd: skip udp_dual_stack if not supported (Santiago
    Gimeno)
  * linux: don't retry dup2/dup3 on EINTR (Ben Noordhuis)
  * unix: don't retry dup2/dup3 on EINTR (Ben Noordhuis)
  * test: fix -Wtautological-pointer-compare warnings (Saúl Ibarra
    Corretgé)
  * win: map ERROR_BAD_PATHNAME to UV_ENOENT (Tony Kelman)
  * test: fix test/test-tty.c for AIX (Imran Iqbal)
  * android: support api level less than 21 (kkdaemon)
  * fsevents: fix race on simultaneous init+close (Fedor Indutny)
  * linux,fs: fix p{read,write}v with a 64bit offset (Saúl Ibarra
    Corretgé)
  * fs: add uv_fs_realpath() (Yuval Brik)
  * win: fix path for removed and renamed fs events (Joran Dirk
    Greef)
  * win: do not read more from stream than available (Jeremy
    Whitlock)
  * test: test that uv_close() doesn't corrupt QUEUE (Andrey Mazo)
  * unix: fix uv_fs_event_stop() from fs_event_cb (Andrey Mazo)
  * test: fix self-deadlocks in thread_rwlock_trylock (Ben
    Noordhuis)
  * src: remove non ascii character (sztomi)
  * test: fix test udp_multicast_join6 for AIX (Imran Iqbal)
* Sun Dec  6 2015 mpluskal@suse.com
- Make building more verbose
* Sat Oct  3 2015 mrueckert@suse.de
- Update to 1.7.5
  - unix: Support atomic compare & swap xlC on AIX (nmushell)
  - unix: Fix including uv-aix.h on AIX (nmushell)
  - unix: consolidate rwlock tryrdlock trywrlock errors (Saúl
    Ibarra Corretgé)
  - unix, win: consolidate mutex trylock errors (Saúl Ibarra
    Corretgé)
  - darwin: fix memory leak in uv_cpu_info (Jianghua Yang)
  - test: add tests for the uv_rwlock implementation (Bert Belder)
  - win: redo/fix the uv_rwlock APIs (Bert Belder)
  - win: don't fetch function pointers to SRWLock APIs (Bert
    Belder)
- Changes for 1.7.4:
  - doc: uv_read_start and uv_read_cb clarifications (Ben Trask)
  - freebsd: obtain true uptime through clock_gettime() (Jianghua
    Yang)
  - win, tty: do not convert \r to \r\n (Colin Snover)
  - build,gyp: add DragonFly to the list of OSes (Michael Neumann)
  - fs: fix bug in sendfile for DragonFly (Michael Neumann)
  - doc: add uv_dlsym() return type (Brian White)
  - tests: fix fs tests run w/o full getdents support (Jeremy
    Whitlock)
  - doc: fix typo (Devchandra Meetei Leishangthem)
  - doc: fix uv-unix.h location (Sakthipriyan Vairamani)
  - unix: fix error check when closing process pipe fd (Ben
    Noordhuis)
  - test,freebsd: fix ipc_listen_xx_write tests (Santiago Gimeno)
  - win: fix unsavory rwlock fallback implementation (Bert Belder)
  - doc: clarify repeat timer behavior (Eli Skeggs)
- Changes for 1.7.3:
  - threadpool: fix thread starvation bug (Ben Noordhuis)
- Changes for 1.7.2:
  - unix, win: make uv_loop_init return on error (Willem Thiart)
  - win: reset pipe handle for pipe servers (Saúl Ibarra Corretgé)
  - win: fix replacing pipe handle for pipe servers (Saúl Ibarra
    Corretgé)
  - win: fix setting pipe pending instances after bind (Saúl Ibarra
    Corretgé)
- Changes for 1.7.1:
  - doc: document the procedure for verifying releases (Saúl Ibarra
    Corretgé)
  - doc: add note about Windows binaries to the README (Saúl Ibarra
    Corretgé)
  - doc: use long GPG IDs in MAINTAINERS.md (Saúl Ibarra Corretgé)
  - Revert "stream: squelch ECONNRESET error if already closed"
    (Saúl Ibarra Corretgé)
  - doc: clarify uv_read_stop() is idempotent (Corbin Simpson)
  - unix: OpenBSD's setsockopt needs an unsigned char for multicast
    (Zachary Hamm)
  - test: Fix two memory leaks (Karl Skomski)
  - unix,win: return EINVAL on nullptr args in uv_fs_{read,write}
    (Karl Skomski)
  - win: set accepted TCP sockets as non-inheritable (Saúl Ibarra
    Corretgé)
  - unix: remove superfluous parentheses in fs macros (Ben
    Noordhuis)
  - unix: don't copy arguments for sync fs requests (Ben Noordhuis)
  - test: plug small memory leak in unix test runner (Ben
    Noordhuis)
  - unix,windows: allow NULL loop for sync fs requests (Ben
    Noordhuis)
  - unix,windows: don't assert on unknown error code (Ben
    Noordhuis)
  - stream: retry write on EPROTOTYPE on OSX (Brian White)
  - common: fix use of snprintf on Windows (Saúl Ibarra Corretgé)
  - tests: refactored fs watch_dir tests for stability (Jeremy
    Whitlock)
- Changes for 1.7.0:
  - win,stream: add slot to remember CRT fd (Bert Belder)
  - win,pipe: properly close when created from CRT fd (Bert Belder)
  - win,pipe: don't close fd 0-2 (Bert Belder)
  - win,tty: convert fd -> handle safely (Bert Belder)
  - win,tty: properly close when created from CRT fd (Bert Belder)
  - win,tty: don't close fd 0-2 (Bert Belder)
  - win,fs: don't close fd 0-2 (Bert Belder)
  - win: include "malloc.h" (Cheng Zhao)
  - windows: MSVC 2015 has C99 inline (Jason Williams)
  - dragonflybsd: fixes for nonblocking and cloexec (Michael
    Neumann)
  - dragonflybsd: use sendfile(2) for uv_fs_sendfile (Michael
    Neumann)
  - dragonflybsd: fix uv_exepath (Michael Neumann)
  - win,fs: Fixes align(8) directive on mingw (Stefano Cristiano)
  - unix, win: prevent replacing fd in uv_{udp,tcp,pipe}_t (Saúl
    Ibarra Corretgé)
  - win: move logic to set socket non-inheritable to
    uv_tcp_set_socket (Saúl Ibarra Corretgé)
  - unix, win: add ability to create tcp/udp sockets early (Saúl
    Ibarra Corretgé)
  - test: retry select() on EINTR, honor milliseconds (Ben
    Noordhuis)
  - unix: consolidate tcp and udp bind error (Saúl Ibarra Corretgé)
  - test: conditionally skip udp_ipv6_multicast_join6 (heshamsafi)
  - core: add UV_VERSION_HEX macro (Saúl Ibarra Corretgé)
  - doc: add section with version-checking macros and functions
    (Saúl Ibarra Corretgé)
  - tty: cleanup handle if uv_tty_init fails (Saúl Ibarra Corretgé)
  - darwin: save a fd when FSEvents is used (Saúl Ibarra Corretgé)
  - win: fix returning thread id in uv_thread_self (Saúl Ibarra
    Corretgé)
  - common: use offsetof for QUEUE_DATA (Saúl Ibarra Corretgé)
  - win: remove UV_HANDLE_CONNECTED (A. Hauptmann)
  - docs: add Windows specific note for uv_fs_open (Saúl Ibarra
    Corretgé)
  - doc: add note about uv_fs_scandir (Saúl Ibarra Corretgé)
  - test,unix: reduce stack size of watchdog threads (Ben
    Noordhuis)
  - win: add support for recursive file watching (Saúl Ibarra
    Corretgé)
  - win,tty: support consoles with non-default colors (John
    McNamee)
  - doc: add missing variable name (Yosuke Furukawa)
  - stream: squelch ECONNRESET error if already closed (Santiago
    Gimeno)
  - build: remove ancient condition from common.gypi (Saúl Ibarra
    Corretgé)
  - tests: skip some tests when network is unreachable (Luca Bruno)
  - build: proper support for android cross compilation (guworks)
  - android: add missing include to pthread-fixes.c (RossBencina)
  - test: fix compilation warning (Saúl Ibarra Corretgé)
  - doc: add a note about uv_dirent_t.type (Saúl Ibarra Corretgé)
  - win,test: fix shared library build (Saúl Ibarra Corretgé)
  - test: fix compilation warning (Santiago Gimeno)
  - build: add experimental Windows installer (Roger A. Light)
  - threadpool: send signal only when queue is empty (chenttuuvv)
  - aix: fix uv_exepath with relative paths (Richard Lau)
  - build: fix version syntax in AppVeyor file (Saúl Ibarra
    Corretgé)
  - unix: allow nbufs > IOV_MAX in uv_fs_{read,write} (ronkorving)
* Wed Aug  5 2015 mpluskal@suse.com
- Update to 1.6.1
  * unix: handle invalid _SC_GETPW_R_SIZE_MAX values (cjihrig)
- Changes for 1.6.0
  * aix: fix setsockopt for multicast options (Michael)
  * unix: don't block for io if any io handle is primed (Saúl
    Ibarra Corretgé)
  * windows: MSVC 2015 has snprintf() (Rui Abreu Ferreira)
  * windows: Add VS2015 support to vcbuild.bat (Jason Williams)
  * doc: fix typo in tcp.rst (Igor Soarez)
  * linux: work around epoll bug in kernels < 2.6.37 (Ben
    Noordhuis)
  * unix,win: add uv_os_homedir() (cjihrig)
  * stream: fix `select()` race condition (Fedor Indutny)
  * unix: prevent infinite loop in uv__run_pending (Saúl Ibarra
    Corretgé)
  * unix: make sure UDP send callbacks are asynchronous (Saúl
    Ibarra Corretgé)
  * test: fix `platform_output` netmask printing. (Andrew Paprocki)
  * aix: add ahafs autoconf detection and README notes (Andrew
    Paprocki)
  * core: add ability to customize memory allocator (Saúl Ibarra
    Corretgé)
- Changes for 1.5.0
  * doc: clarify that the thread pool primites are not thread safe
    (Andrius Bentkus)
  * aix: always deregister closing fds from epoll (Michael)
  * unix: fix glibc-2.20+ macro incompatibility (Massimiliano
    Torromeo)
  * doc: add Sphinx plugin for generating links to man pages
    (Saúl Ibarra Corretgé)
  * doc: link system and library calls to man pages (Saúl
    Ibarra Corretgé)
  * doc: document uv_getnameinfo_t.{host|service} (Saúl Ibarra
    Corretgé)
  * build: update the location of gyp (Stephen von Takach)
  * win: name all anonymous structs and unions (TomCrypto)
  * linux: work around epoll bug in kernels 3.10-3.19 (Ben
    Noordhuis)
  * darwin: fix size calculation in select() fallback (Ole
    André Vadla Ravnås)
  * solaris: fix setsockopt for multicast options (Julien
    Gilli)
  * test: fix race condition in multithreaded test (Ben Noordhuis)
  * doc: fix long lines in tty.rst (Ben Noordhuis)
  * test: use UV_TTY_MODE_* values in tty test (Ben Noordhuis)
  * unix: don't clobber errno in uv_tty_reset_mode() (Ben
    Noordhuis)
  * unix: reject non-tty fds in uv_tty_init() (Ben Noordhuis)
  * win: fix pipe blocking writes (Alexis Campailla)
  * build: fix cross-compiling for iOS (Steven Kabbes)
  * win: remove unnecessary malloc.h
  * include: use `extern "c++"` for defining C++ code (Kazuho Oku)
  * unix: reap child on execvp() failure (Ryan Phillips)
  * windows: fix handle leak on EMFILE (Brian Green)
  * test: fix tty_file, close handle if initialized (Saúl Ibarra
    Corretgé)
  * doc: clarify what uv_*_open accepts (Saúl Ibarra Corretgé)
  * doc: clarify that we don't maintain external doc resources
    (Saúl Ibarra Corretgé)
  * build: add documentation for ninja support (Devchandra
    Meetei Leishangthem)
  * doc: document uv_buf_t members (Corey Farrell)
  * linux: fix epoll_pwait() fallback on arm64 (Ben Noordhuis)
  * android: fix compilation warning (Saúl Ibarra Corretgé)
  * unix: don't close the fds we just setup (Sam Roberts)
  * test: spawn child replacing std{out,err} to stderr
  * unix: fix swapping fds order in uv_spawn
  * unix: fix potential bug if dup2 fails in uv_spawn
  * test: remove LOG and LOGF variadic macros
  * win: fix uv_fs_access on directories
  * win: fix of double free in uv_uptime
  * unix: open "/dev/null" instead of "/" for emfile_fd
  * docs: add some missing words
  * unix: clean up uv_fs_open() O_CLOEXEC logic
  * build: set SONAME for shared library in uv.gyp
  * windows: define snprintf replacement as inline instead of static
  * win: fix unlink of readonly files
  * doc: fix uv_run(UV_RUN_DEFAULT) description
  * linux: intercept syscall when running under memory sanitizer
  * aix: fix uv_interface_addresses return value
  * windows: defer reporting TCP write failure until next tick
  * test: add test for deferred TCP write failure
* Mon Mar  2 2015 tchvatal@suse.com
- Version bump to 1.4.2:
  * stream: ignore EINVAL for SO_OOBINLINE on OS X (Fedor Indutny)
  * win: don't use inline keyword in thread.c (Ben Noordhuis)  * windows: fix
  * setting dirent types on uv_fs_scandir_next (Saúl Ibarra Corretgé)  *
  * unix,windows: make uv_thread_create() return errno (Ben Noordhuis)  * tty:
  * fix build for SmartOS (Julien Gilli)  * unix: fix for uv_async data race
  * (Michael Penick)  * unix, windows: map EHOSTDOWN errno (Ben Noordhuis)  *
  * stream: use SO_OOBINLINE on OS X (Fedor Indutny)
* Thu Feb 12 2015 tchvatal@suse.com
- Version bump to 1.4.0 which is the latest release
- Cleanup with the spec cleaner
- Try to enable tests and they currently fail
* Mon Sep 15 2014 00:00:00 UTC - daxim@cpan.org
- update to v0.11.29
* Mon Aug 11 2014 00:00:00 UTC - daxim@cpan.org
- update to v0.11.28
* Wed Apr 30 2014 00:00:00 UTC - dmacvicar@suse.de
- update to 0.11.24
- install pkg-config file
* Sun Apr 13 2014 dmitry_r@opensuse.org
- Update to version 0.11.23
  * bug fixes
* Mon Mar 10 2014 daxim@cpan.org
- update to v0.11.21
* Fri Jan 31 2014 daxim@cpan.org
- initial packaging of v0.11.19
